pub struct Span { /* private fields */ }Expand description
Represents a contiguous segment of source code.
start and end are byte offsets into the source code,
while line and column represent the human-readable
position of the span.
This structure can be used for highlighting errors, diagnostics,
or feeding external crates like ariadne.
Example
use rhai_trace::Span;
let span = Span::new(10, 20, 2, 5);
println!("Span covers bytes {}..{} on line {}", span.start(), span.end(), span.line());Implementations
Sourceimpl Span
impl Span
Sourcepub fn new(start: usize, end: usize, line: usize, column: usize) -> Self
pub fn new(start: usize, end: usize, line: usize, column: usize) -> Self
Creates a new Span from byte offsets, line, and column.
Sourcepub fn from_pos(script: &str, pos: &Position) -> Self
pub fn from_pos(script: &str, pos: &Position) -> Self
Creates a Span from a Rhai Position and the script text.
Computes byte offsets based on line and column.
Sourcepub fn from_rhai_start_end_pos(
script: &str,
start: &Position,
end: &Position,
) -> Self
pub fn from_rhai_start_end_pos( script: &str, start: &Position, end: &Position, ) -> Self
Creates a Span from Rhai start and end Positions.
Sourcepub fn from_rhai_span(script: &str, rhai_span: Span, pos: &Position) -> Self
pub fn from_rhai_span(script: &str, rhai_span: Span, pos: &Position) -> Self
Converts a Rhai Span to our Span type using a reference Position.